# XMP/C and XMP/Fortran
## Using GASNet for coarray, lock/unlock, and post/wait (local-view operations)
The Omni compiler uses GASNet for local-view operations, and also uses MPI library for global-view operations.
However, GASNet cannot use MPI communication except for mpi-conduit at the same time.
(In detail, please read a section "MPI Interoperability" in README of GASNet)

Therefore, when using both local-view and global-view operations at the same time,
XMP application may not be executed.
If you want to use both local-view and global-view operations in one application,
you need to use xmp_sync_all() or barrier directive to divide communication.

---
  /* ... local-view program ... */

  xmp_sync_all(&status);

  /* ... global-view program ... */

 #pragma xmp barrier

  /* ... local-view program ... */
---

## On the K computer, FX100, and FX10
* The number of coarrays in an application is 508 or less
* An application cannot be used in more than 82,944 processes
* The coarray transfer data size is 16,777,212 (2^24-4) bytes or less
* Post tag value is between 0 and 14 (0 <= tag <= 14)

# For module file of XcalableMP/Fortran
The omni compiler uses an .xmod file, which is a particular file for using a module file.
Therefore, for example, even to generate a normal .mod file by gfortran,
the .mod file cannot be used in the omni compiler.

In order to transform a .mod file to an .xmod file, the omni compiler provides a T_Module command.
The T_Module command supports the .mod file generated by gfortran-4.4, 4.7, and 4.9.
In order to build the T_Module command, you add the --enable-mod2xmod option to ./configure.
Note that the build process of T_Module needs mpfr and gmp.

$ ./configure --enable-mod2xmod

For example, to generate test.xmod from test.mod, you execute as follows.

$ T_module test.mod

